@@ -1,4 +1,4 @@
 pub mod rapidmath;
 pub mod constants;
 pub mod sets;
-mod vectors;
\ No newline at end of file
+pub mod vectors;
\ No newline at end of file
